@@ -3,9 +3,19 @@ from ._code_repr import HasRepr
 from ._external import external
 from ._external import outsource
 from ._inline_snapshot import snapshot
+from ._is import Is
 from ._types import Category
 from ._types import Snapshot
 
-__all__ = ["snapshot", "external", "outsource", "customize_repr", "HasRepr"]
+__all__ = [
+    "snapshot",
+    "external",
+    "outsource",
+    "customize_repr",
+    "HasRepr",
+    "Is",
+    "Category",
+    "Snapshot",
+]
 
-__version__ = "0.14.0"
+__version__ = "0.19.3"
